@@ -1,6 +1,6 @@
 #!/bin/bash
 
-UTDICDATE="20210322"
+UTDICDATE="20210329"
 REVISION="1"
 
 #altcannadic="true"
@@ -10,6 +10,7 @@ REVISION="1"
 neologd="true"
 #nicoime="true"
 #skk="true"
+#sudachidict="true"
 
 
 # ==============================================================================
@@ -17,6 +18,10 @@ neologd="true"
 # ==============================================================================
 
 rm -f mozcdic-ut.txt
+rm -f ../mozcdic-ut-*.txt
+rm ../*/*.zip
+rm ../*/*.gz
+#rm ../*/*.bz2
 
 cd ../mozc/
 sh get-official-mozc.sh
@@ -38,8 +43,6 @@ ruby apply-jawiki-costs.rb mozcdic-ut.txt.extracted
 
 rm -f ../mozcdic*-ut-*.txt
 mv mozcdic-ut.txt.extracted ../mozcdic-ut-$UTDICDATE.$REVISION.txt
-#cat ../zipcode/mozcdic-zipcode-jigyosyo.txt ../zipcode/mozcdic-zipcode-ken_all.txt \
-#> ../mozcdic-zipcode-ut-$UTDICDATE.$REVISION.txt
 
 
 # ==============================================================================
